@@ -98,7 +98,7 @@ static void cb_xfce_backdrop_image_files_changed(GFileMonitor     *monitor,
                                                  GFileMonitorEvent event,
                                                  gpointer          user_data);
 
-struct _XfceBackdropPriv
+struct _XfceBackdropPrivate
 {
     gint width, height;
     gint bpp;
@@ -361,6 +361,11 @@ cb_xfce_backdrop_image_files_changed(GFileMonitor     *monitor,
                 backdrop->priv->image_files = g_list_delete_link(backdrop->priv->image_files, item);
 
             g_free(changed_file);
+
+            if (backdrop->priv->cycle_timer_id) {
+                g_source_remove(backdrop->priv->cycle_timer_id);
+                backdrop->priv->cycle_timer_id = 0;
+            }
             break;
         case G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT:
             changed_file = g_file_get_path(file);
@@ -650,7 +655,7 @@ xfce_backdrop_choose_chronological(XfceBackdrop *backdrop)
 /* gobject-related functions */
 
 
-G_DEFINE_TYPE(XfceBackdrop, xfce_backdrop, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE(XfceBackdrop, xfce_backdrop, G_TYPE_OBJECT)
 
 
 static void
@@ -658,8 +663,6 @@ xfce_backdrop_class_init(XfceBackdropClass *klass)
 {
     GObjectClass *gobject_class = (GObjectClass *)klass;
 
-    g_type_class_add_private(klass, sizeof(XfceBackdropPriv));
-
     gobject_class->finalize = xfce_backdrop_finalize;
     gobject_class->set_property = xfce_backdrop_set_property;
     gobject_class->get_property = xfce_backdrop_get_property;
@@ -761,8 +764,7 @@ xfce_backdrop_class_init(XfceBackdropClass *klass)
 static void
 xfce_backdrop_init(XfceBackdrop *backdrop)
 {
-    backdrop->priv = G_TYPE_INSTANCE_GET_PRIVATE(backdrop, XFCE_TYPE_BACKDROP,
-                                                 XfceBackdropPriv);
+    backdrop->priv = xfce_backdrop_get_instance_private(backdrop);
     backdrop->priv->cycle_timer_id = 0;
 
     /* color defaults */
@@ -1780,6 +1782,7 @@ xfce_backdrop_loader_closed_cb(GdkPixbufLoader *loader,
     gint dx, dy, xo, yo;
     gdouble xscale, yscale;
     GdkInterpType interp;
+    gboolean rotated = FALSE;
 
     TRACE("entering");
 
@@ -1796,6 +1799,8 @@ xfce_backdrop_loader_closed_cb(GdkPixbufLoader *loader,
 
     image = gdk_pixbuf_loader_get_pixbuf(loader);
     if(image) {
+        gint iw_orig = gdk_pixbuf_get_width(image);
+
         /* If the image is supposed to be rotated, do that now */
         GdkPixbuf *temp = gdk_pixbuf_apply_embedded_orientation (image);
         /* Do not unref image, gdk_pixbuf_loader_get_pixbuf is transfer none */
@@ -1803,6 +1808,8 @@ xfce_backdrop_loader_closed_cb(GdkPixbufLoader *loader,
 
         iw = gdk_pixbuf_get_width(image);
         ih = gdk_pixbuf_get_height(image);
+
+        rotated = (iw_orig != iw);
     }
 
     if(backdrop->priv->width == 0 || backdrop->priv->height == 0) {
@@ -1853,6 +1860,9 @@ xfce_backdrop_loader_closed_cb(GdkPixbufLoader *loader,
         return;
     }
 
+    xscale = (gdouble)w / iw;
+    yscale = (gdouble)h / ih;
+
     switch(istyle) {
         case XFCE_BACKDROP_IMAGE_NONE:
             /* do nothing */
@@ -1898,12 +1908,13 @@ xfce_backdrop_loader_closed_cb(GdkPixbufLoader *loader,
 
         case XFCE_BACKDROP_IMAGE_STRETCHED:
             gdk_pixbuf_composite(image, final_image, 0, 0, w, h,
-                    0, 0, 1, 1, interp, 255);
+                    0, 0,
+                    rotated ? xscale : 1,
+                    rotated ? yscale : 1,
+                    interp, 255);
             break;
 
         case XFCE_BACKDROP_IMAGE_SCALED:
-            xscale = (gdouble)w / iw;
-            yscale = (gdouble)h / ih;
             if(xscale < yscale) {
                 yscale = xscale;
                 xo = 0;
@@ -1917,14 +1928,14 @@ xfce_backdrop_loader_closed_cb(GdkPixbufLoader *loader,
             dy = yo;
 
             gdk_pixbuf_composite(image, final_image, dx, dy,
-                    iw * xscale, ih * yscale, xo, yo, 1, 1,
+                    iw * xscale, ih * yscale, xo, yo,
+                    rotated ? xscale : 1,
+                    rotated ? yscale : 1,
                     interp, 255);
             break;
 
         case XFCE_BACKDROP_IMAGE_ZOOMED:
         case XFCE_BACKDROP_IMAGE_SPANNING_SCREENS:
-            xscale = (gdouble)w / iw;
-            yscale = (gdouble)h / ih;
             if(xscale < yscale) {
                 xscale = yscale;
                 xo = (w - (iw * xscale)) * 0.5;
@@ -1936,7 +1947,10 @@ xfce_backdrop_loader_closed_cb(GdkPixbufLoader *loader,
             }
 
             gdk_pixbuf_composite(image, final_image, 0, 0,
-                    w, h, xo, yo, 1, 1, interp, 255);
+                    w, h, xo, yo,
+                    rotated ? xscale : 1,
+                    rotated ? yscale : 1,
+                    interp, 255);
             break;
 
         default:
