@@ -1,7 +1,7 @@
 /*
  *  xfdesktop - xfce4's desktop manager
  *
- *  Copyright (c) 2004 Brian Tarricone, <bjt23@cornell.edu>
+ *  Copyright (c) 2004-2007 Brian Tarricone, <bjt23@cornell.edu>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,16 +14,15 @@
  *  GNU Library General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, write to the Free Software Foundation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
 #ifndef _XFCE_DESKTOP_H_
 #define _XFCE_DESKTOP_H_
 
-#include <glib.h>
-#include <glib-object.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
+#include <xfconf/xfconf.h>
 
 #include "xfce-backdrop.h"
 
@@ -38,7 +37,7 @@ G_BEGIN_DECLS
 
 typedef struct _XfceDesktop XfceDesktop;
 typedef struct _XfceDesktopClass XfceDesktopClass;
-typedef struct _XfceDesktopPriv XfceDesktopPriv;
+typedef struct _XfceDesktopPrivate XfceDesktopPrivate;
 
 typedef void (*SessionLogoutFunc)();
 
@@ -52,28 +51,33 @@ typedef enum
 struct _XfceDesktop
 {
     GtkWindow window;
-    
+
     /*< private >*/
-    XfceDesktopPriv *priv;
+    XfceDesktopPrivate *priv;
 };
 
 struct _XfceDesktopClass
 {
     GtkWindowClass parent_class;
+
+    /*< signals >*/
+
+    /* for the app menu/file context menu */
+    void (*populate_root_menu)(XfceDesktop *desktop,
+                               GtkMenuShell *menu);
+
+    /* for the windowlist menu */
+    void (*populate_secondary_root_menu)(XfceDesktop *desktop,
+                                         GtkMenuShell *menu);
 };
 
-GType xfce_desktop_get_type                     () G_GNUC_CONST;
+GType xfce_desktop_get_type                     (void) G_GNUC_CONST;
 
-GtkWidget *xfce_desktop_new(GdkScreen *gscreen);
+GtkWidget *xfce_desktop_new(GdkScreen *gscreen,
+                            XfconfChannel *channel,
+                            const gchar *property_prefix);
 
-guint xfce_desktop_get_n_monitors(XfceDesktop *desktop);
-
-gint xfce_desktop_get_width(XfceDesktop *desktop);
-gint xfce_desktop_get_height(XfceDesktop *desktop);
-
-void xfce_desktop_set_xinerama_stretch(XfceDesktop *desktop,
-                                       gboolean stretch);
-gboolean xfce_desktop_get_xinerama_stretch(XfceDesktop *desktop);
+gint xfce_desktop_get_n_monitors(XfceDesktop *desktop);
 
 void xfce_desktop_set_icon_style(XfceDesktop *desktop,
                                  XfceDesktopIconStyle style);
@@ -82,19 +86,34 @@ XfceDesktopIconStyle xfce_desktop_get_icon_style(XfceDesktop *desktop);
 void xfce_desktop_set_icon_size(XfceDesktop *desktop,
                                 guint icon_size);
 
-void xfce_desktop_set_icon_use_system_font_size(XfceDesktop *desktop,
-                                                gboolean use_system);
+void xfce_desktop_set_primary(XfceDesktop *desktop,
+                              gboolean primary);
+
+void xfce_desktop_set_use_icon_font_size(XfceDesktop *desktop,
+                                         gboolean use_system);
 void xfce_desktop_set_icon_font_size(XfceDesktop *desktop,
                                      guint font_size_points);
 
+void xfce_desktop_set_center_text(XfceDesktop *desktop,
+                                  gboolean center_text);
+
 void xfce_desktop_set_session_logout_func(XfceDesktop *desktop,
                                           SessionLogoutFunc logout_func);
 
 void xfce_desktop_freeze_updates(XfceDesktop *desktop);
 void xfce_desktop_thaw_updates(XfceDesktop *desktop);
 
-XfceBackdrop *xfce_desktop_peek_backdrop(XfceDesktop *desktop,
-                                         guint monitor);
+
+void xfce_desktop_popup_root_menu(XfceDesktop *desktop,
+                                  guint button,
+                                  guint activate_time);
+void xfce_desktop_popup_secondary_root_menu(XfceDesktop *desktop,
+                                            guint button,
+                                            guint activate_time);
+
+void xfce_desktop_refresh(XfceDesktop *desktop, gboolean advance_wallpaper);
+
+void xfce_desktop_arrange_icons(XfceDesktop *desktop);
 
 G_END_DECLS
 
